#!/bin/sh
#
# $Id: acct.prolog,v 1.12 2008/10/31 16:02:42 dtynan Exp $
#
# Copyright (c) 2005, Kalopa Research Limited.  All rights reserved.
# This is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published
# by the Free Software Foundation; either version 2, or (at your
# option) any later version.
#
# It is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
# License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this product; see the file COPYING.  If not, write to
# the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139,
# USA.
#
# THIS SOFTWARE IS PROVIDED BY KALOPA RESEARCH LIMITED "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL KALOPA
# RESEARCH LIMITED BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
# USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
# AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
# THE POSSIBILITY OF SUCH DAMAGE.
#
# ABSTRACT
# Run this script before doing anything for any of the companies.
#
# $Log: acct.prolog,v $
# Revision 1.12  2008/10/31 16:02:42  dtynan
# Changed to new 'tag' mechanism.
#
# Revision 1.11  2008/01/15 18:10:43  dtynan
# Changed to use new company name and copyright, also fixed a few old
# files with the wrong license.
#
# Revision 1.10  2008/01/15 14:01:35  dtynan
# Now uses the runcom system.
#
# Revision 1.9  2007/05/28 10:29:57  dtynan
# Changed the backup directory somewhat.
#
# Revision 1.8  2005/08/13 13:01:19  dtynan
# Use environment variables rather than hard-coded paths and passwords.
#
# Revision 1.7  2005/08/12 20:02:54  dtynan
# Changed the way the backup works.
#
# Revision 1.6  2005/08/12 19:40:37  dtynan
# Added a debug 'env' to the prolog and renamed the sendinvoice program.
#
# Revision 1.5  2005/03/22 09:41:22  dtynan
# Extensive upgrade to make sure the copyright block was
# consistent and GPL'ed.
#
# Revision 1.4  2005/03/08 15:52:17  dtynan
# Make the year part of the backup filename.
#
# Revision 1.3  2005/02/17 14:17:45  dtynan
# Removed backup script (now part of prolog processing).
#
# Revision 1.2  2005/02/17 11:43:32  dtynan
# Back up the database before (not after) overnight account runs.
#
# Revision 1.1  2005/02/17 11:00:59  dtynan
# Uses new format where there are prolog and epilog scripts, and all
# scripts are executed by being piped to the one email message.
#
if [ $# -lt 4 ]
then
	echo "?Error - invalid number of arguments."
	exit 1
fi

tag=$1
day=$2
mon=$3
year=$4

#
# Do preliminary monthly work.
#
echo "Processing pre-accounting tasks..."

#
# Do a nightly backup of the databases...
DBOPT="-h $BEANIEHOST -u beanie --password=$DBPASSWD"
DBASE=`echo "show databases" | mysql $DBOPT | grep ^beanie`
DUMPOPT="--add-drop-table $DBOPT"

bkdir=/img/dumps/beanie/`date +%Y`
dstr=`date +%m%d`
mkdir -p $bkdir

echo "Backing up main directory..."
tar czf $bkdir/beaniefiles.$dstr.tgz -C $BEANIEROOT .

for db in $DBASE
do
	echo "Backing up database $db..."
	mysqldump $DUMPOPT $db | gzip > $bkdir/$db.$dstr.gz
done

#
# Send newsletter to customers...
sendnews $year$mon$day

#
# All done!
exit 0
